==> zio-aws-dynamodb_3-5.17.195.1-sources.jar: zio/aws/dynamodb/model/ParameterizedStatement.scala <==
package zio.aws.dynamodb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.dynamodb.model.primitives.PartiQLStatement
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ParameterizedStatement(
    statement: PartiQLStatement,
    parameters: Optional[Iterable[zio.aws.dynamodb.model.AttributeValue]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement = {
    import ParameterizedStatement.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
      .builder()
      .statement(PartiQLStatement.unwrap(statement): java.lang.String)
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .build()
  }
  def asReadOnly: zio.aws.dynamodb.model.ParameterizedStatement.ReadOnly =
    zio.aws.dynamodb.model.ParameterizedStatement.wrap(buildAwsValue())
}
object ParameterizedStatement {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dynamodb.model.ParameterizedStatement =
      zio.aws.dynamodb.model.ParameterizedStatement(
        statement,
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def statement: PartiQLStatement
    def parameters
        : Optional[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]]
    def getStatement: ZIO[Any, Nothing, PartiQLStatement] =
      ZIO.succeed(statement)
    def getParameters: ZIO[Any, AwsError, List[
      zio.aws.dynamodb.model.AttributeValue.ReadOnly
    ]] = AwsError.unwrapOptionField("parameters", parameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
  ) extends zio.aws.dynamodb.model.ParameterizedStatement.ReadOnly {
    override val statement: PartiQLStatement =
      zio.aws.dynamodb.model.primitives.PartiQLStatement(impl.statement())
    override val parameters
        : Optional[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.dynamodb.model.AttributeValue.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
  ): zio.aws.dynamodb.model.ParameterizedStatement.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dynamodb_3-7.21.15.11-sources.jar: zio/aws/dynamodb/model/ParameterizedStatement.scala <==
package zio.aws.dynamodb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.dynamodb.model.primitives.PartiQLStatement
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ParameterizedStatement(
    statement: PartiQLStatement,
    parameters: Optional[Iterable[zio.aws.dynamodb.model.AttributeValue]] =
      Optional.Absent,
    returnValuesOnConditionCheckFailure: Optional[
      zio.aws.dynamodb.model.ReturnValuesOnConditionCheckFailure
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement = {
    import ParameterizedStatement.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
      .builder()
      .statement(PartiQLStatement.unwrap(statement): java.lang.String)
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .optionallyWith(
        returnValuesOnConditionCheckFailure.map(value => value.unwrap)
      )(_.returnValuesOnConditionCheckFailure)
      .build()
  }
  def asReadOnly: zio.aws.dynamodb.model.ParameterizedStatement.ReadOnly =
    zio.aws.dynamodb.model.ParameterizedStatement.wrap(buildAwsValue())
}
object ParameterizedStatement {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dynamodb.model.ParameterizedStatement =
      zio.aws.dynamodb.model.ParameterizedStatement(
        statement,
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        returnValuesOnConditionCheckFailure.map(value => value)
      )
    def statement: PartiQLStatement
    def parameters
        : Optional[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]]
    def returnValuesOnConditionCheckFailure
        : Optional[zio.aws.dynamodb.model.ReturnValuesOnConditionCheckFailure]
    def getStatement: ZIO[Any, Nothing, PartiQLStatement] =
      ZIO.succeed(statement)
    def getParameters: ZIO[Any, AwsError, List[
      zio.aws.dynamodb.model.AttributeValue.ReadOnly
    ]] = AwsError.unwrapOptionField("parameters", parameters)
    def getReturnValuesOnConditionCheckFailure: ZIO[
      Any,
      AwsError,
      zio.aws.dynamodb.model.ReturnValuesOnConditionCheckFailure
    ] = AwsError.unwrapOptionField(
      "returnValuesOnConditionCheckFailure",
      returnValuesOnConditionCheckFailure
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
  ) extends zio.aws.dynamodb.model.ParameterizedStatement.ReadOnly {
    override val statement: PartiQLStatement =
      zio.aws.dynamodb.model.primitives.PartiQLStatement(impl.statement())
    override val parameters
        : Optional[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.dynamodb.model.AttributeValue.wrap(item)
          }.toList
        )
    override val returnValuesOnConditionCheckFailure
        : Optional[zio.aws.dynamodb.model.ReturnValuesOnConditionCheckFailure] =
      zio.aws.core.internal
        .optionalFromNullable(impl.returnValuesOnConditionCheckFailure())
        .map(value =>
          zio.aws.dynamodb.model.ReturnValuesOnConditionCheckFailure.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.ParameterizedStatement
  ): zio.aws.dynamodb.model.ParameterizedStatement.ReadOnly = new Wrapper(impl)
}
